==> postcss-selector-namespace-1.2.0.tgz: package/README.md <==
# postcss-selector-namespace [![Build Status](https://travis-ci.org/topaxi/postcss-selector-namespace.svg?branch=master)](https://travis-ci.org/topaxi/postcss-selector-namespace)

# Installation

```bash
$ npm install postcss-selector-namespace
```

## Usage

```javascript
var postcss = require('postcss')
var selectorNamespace = require('postcss-selector-namespace')

var output = postcss()
  .use(selectorNamespace({ selfSelector: ':--component', namespace: 'my-component' }))
  .process(require('fs').readFileSync('input.css', 'utf8'))
  .css
```

`input.css`
```css
:--component {
  color: black;
}

:--component.danger {
  color: red;
}

h1, .h1 {
  font-weight: bold;
}
```

will output the following css:

```css
.my-component {
  color: black;
}

.my-component.danger {
  color: red;
}

.my-component h1, .my-component .h1 {
  font-weight: bold;
}
```

Prepending [`:root`](https://developer.mozilla.org/en-US/docs/Web/CSS/:root) to a selector prevents the selector from being namespaced:

```css
:root h1 {
  font-weight: bold;
}
```

will output the selector without any modification:

```css
:root h1 {
  font-weight: bold;
}
```

## Options

### `namespace`

(default: `'.self'`)

The selector to prepend to each selector.

### `selfSelector`

(default: `:--namespace`)

The selector to use to apply rules directly to your namespace selector.

### `ignoreRoot`

(default: `true`)

Selector won't be namespaced if they start with the `:root` pseudo-class.

### `rootSelector`

(default: `:root`)

If prefixed with this selector, selectors won't be namespaced.

### `dropRoot`

(default: `true`)

If `true`, the `rootSelector` will be stripped from the output.

---

## [License](LICENSE)

==> postcss-selector-namespace-1.2.1.tgz: package/README.md <==
# postcss-selector-namespace [![Build Status](https://travis-ci.org/topaxi/postcss-selector-namespace.svg?branch=master)](https://travis-ci.org/topaxi/postcss-selector-namespace)

# Installation

```bash
$ npm install postcss-selector-namespace
```

## Usage

```javascript
var postcss = require('postcss')
var selectorNamespace = require('postcss-selector-namespace')

var output = postcss()
  .use(selectorNamespace({ selfSelector: ':--component', namespace: 'my-component' }))
  .process(require('fs').readFileSync('input.css', 'utf8'))
  .css
```

`input.css`
```css
:--component {
  color: black;
}

:--component.danger {
  color: red;
}

h1, .h1 {
  font-weight: bold;
}
```

will output the following css:

```css
.my-component {
  color: black;
}

.my-component.danger {
  color: red;
}

.my-component h1, .my-component .h1 {
  font-weight: bold;
}
```

Prepending [`:root`](https://developer.mozilla.org/en-US/docs/Web/CSS/:root) to a selector prevents the selector from being namespaced:

```css
:root h1 {
  font-weight: bold;
}
```

will output the selector without any namespace:

```css
h1 {
  font-weight: bold;
}
```

## Options

### `namespace`

(default: `'.self'`)

The selector to prepend to each selector.

### `selfSelector`

(default: `:--namespace`)

The selector to use to apply rules directly to your namespace selector.

### `ignoreRoot`

(default: `true`)

Selector won't be namespaced if they start with the `:root` pseudo-class.

### `rootSelector`

(default: `:root`)

If prefixed with this selector, selectors won't be namespaced.

### `dropRoot`

(default: `true`)

If `true`, the `rootSelector` will be stripped from the output.

---

## [License](LICENSE)
